function ifo =AdV_issue_F_v00r02(varargin)

% IFOMODEL returns a structure describing an IFO for use in
% benchmark programs and noise simulator. Part of the bench
% package, which provides science-grounded figures of merit for
% comparing interferometric gravitational wave detector designs.
%

%
% Included stray-light noise from squeezer (J Harms 2017/02/27)
%
% Included Squeezing configuration (G. Gemme 2016/06/07)
% Moved main parameters to the beginning of file (G. Gemme 2016/06/07)
%
% Id: IFOModel.m,F_v00r01 2016/06/06
% thermal noise of the coatings hard wired and given by LMA
% recovered compatibility of the code with LIGO (M.Punturo)
%
% Id: IFOModel.m,E_v00r01 2013/09/24
% introduced OMC thermorefractive noise
%
% Id: IFOModel.m,D_v00r01 2012/11/05
% introduced actual AdV payload
% VIR-0073C-12
% * References:
% * 1. Electro-Optic Handbook, Waynant & Ediger (McGraw-Hill: 1993)
% * 2. LIGO/GEO data/experience
% * 3. Suspension reference design, LIGO-T000012-00
% * 4. Quartz Glass for Optics Data and Properties, Heraeus data sheet,
% *    numbers for suprasil
% * 5. Y.S. Touloukian (ed), Thermophysical Properties of Matter
% *    (IFI/Plenum,1970)
% * 6. Marvin J. Weber (ed) CRC Handbook of laser science and technology,
% *    Vol 4, Pt 2
% * 7. R.S. Krishnan et al.,Thermal Expansion of Crystals, Pergamon Press
% * 8. P. Klocek, Handbook of infrared and optical materials, Marcel Decker,
% *    1991
% * 9. Rai Weiss, electronic log from 5/10/2006
% * 10. Wikipedia online encyclopedia, 2006
% * 11. D.K. Davies, The Generation and Dissipation of Static Charge on
% * dielectrics in a Vacuum, page 29
% * 12. Gretarsson & Harry, Gretarsson thesis
% * 13. Fejer
% * 14. Braginsky

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Main Parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
ifo.Laser.Power = 3;                              % W (exiting from IMC);

%(no SR this value is 1)
ifo.Optics.SRM.Transmittance  = 0.2;                 % Transmittance of SR

%%WITH SR
ifo.Optics.Type = 'SignalRecycled';
%ifo.Optics.SRM.Tunephase = 0.35;                    % SRM tuning, NSNS optimized
                                                    % used to compute @$\phi$ in Eq.\ref{Eq:SRphase}@
                                                    % @$\phi = (\pi - Tunephase) /2$@
ifo.Optics.SRM.Tunephase = 0.0;                    % SRM tuning, wideband
%ifo.Optics.SRM.Transmittance  = 0.20;               % Transmittance of SRM
ifo.Optics.Quadrature.dc = pi/2;                    % demod/detection/homodyne phase

% Define the squeezing you want:
%   None = ignore the squeezer settings
%   Freq Independent = nothing special (no filter cavties)
%   Freq Dependent = applies the specified filter cavites
%   Optimal = find the best squeeze angle, assuming no output filtering                                                    % defined as @$\eta$@ in Eq.@\ref{Eq:HomoRead}@
%ifo.Squeezer.Type = 'None';
ifo.Squeezer.Type = 'Freq Independent';
%ifo.Squeezer.Type = 'Freq Dependent';
%ifo.Squeezer.Type = 'Optimal';
ifo.Squeezer.DCPowerBackScattered = 1.5680e-17;         % Power of carrier field for stray-light noise [W]

%% Infrastructure----------------------------------------------------------
ifo.Infrastructure.Name                       = 'AdV';
ifo.Infrastructure.Length                     = 10000;             % m;

%% Detailed model for residual gas noise--------Giancarlo Cella, 12/05/2009----------------------------
%% Each quantity is a vector which contain the parameter for one kind of
%% molecules, in the following order:
%%
%%                                                  H2O             H2            N2          O2
% Pa; partial pressures GOAL:
ifo.Infrastructure.ResidualGas.pressures        = [10^-7          10^-7          4*10^-8     10^-8  ];
% kg; Mass of the molecule:
ifo.Infrastructure.ResidualGas.masses           = [3.01289*10^-26 3.34765*10^-27 4.7*10^-26  5.3*10^-26  ];
% m^3; Gas polarizability:
ifo.Infrastructure.ResidualGas.polarizabilities = [1.43319*10^-30 7.81917*10^-31 1.63*10^-30 1.49*10^-30];


%% Physical and other constantMaterialss; All in SI units------------------

ifo.Constants.E0      = 8.8541878176e-12;                 % F / m; Permittivity of Free Space
ifo.Constants.hbar    = 1.054572e-34;                     % J - s; (Plancks constant) / (2 * pi)
ifo.Constants.kB      = 1.380658e-23;                     % J / K; Boltzman Constant
ifo.Constants.h       = ifo.Constants.hbar * 2 * pi;      % J - s; Planks constant
ifo.Constants.R       = 8.31447215;                       % J / (K * mol); Gas Constant
ifo.Constants.m_e     = 9.10938291e-31;                   % kg; electron mass
ifo.Constants.c       = 2.99792458e8;                     % m / s; speed of light in vacuum
ifo.Constants.Temp    = 20;                              % K; Temperature of the Vacuum
ifo.Constants.yr      = 365.2422 * 86400;                 % sec; Seconds in a year
ifo.Constants.M_earth = 5.972e24;                         % mass of Earth [kg]
ifo.Constants.R_earth = 6.3781e6;                         % radius of Earth [m]
ifo.Constants.fs      = 16384;                            % Sampling frequency (Hz)
ifo.Constants.AU      = 149597870700;                     % m; Astronomical unit, IAU 2012 Resolution B2
ifo.Constants.parsec  = ifo.Constants.AU * (648000 / pi); % m, IAU 2015 Resolution B2
%ifo.Constants.Mpc     = ifo.Constants.parsec * 1e6       % m, IAU 2015 Resolution B2
ifo.Constants.SolarMassParameter = 1.3271244e20;          % m^3 / s^2; G * MSol, IAU 2015 Resolution B3
ifo.Constants.G       = 6.67408e-11;                      % m^3 / (kg  s^2); Grav. const
                                                          % http://arxiv.org/abs/1507.07956
%ifo.Constants.MSol    = ifo.Constants.SolarMassParameter / ifo.Constants.G % kg; Solar mass

%%%int73 works only with these definitions
ifo.Constants.Mpc = ifo.Constants.yr*ifo.Constants.c*3.26e6    % m
ifo.Constants.MSol = 1.989e30*ifo.Constants.G/ifo.Constants.c^2% m;
%%%%

ifo.Constants.g       = 9.806;                            % m / s^2; grav. acceleration 
                                                          % http://physics.nist.gov/cuu/Constants/ 
ifo.Constants.H0      = 67110;                            % ms^(-1)/Mpc; Hubble const.
                                                          % http://arxiv.org/pdf/1303.5076v3.pdf
ifo.Constants.omegaM  = 0.3175;                           % Mass density parameter 
                                                          % http://arxiv.org/pdf/1303.5076v3.pdf
ifo.Constants.omegaLambda = 1 - ifo.Constants.omegaM;     % Cosmological constant density parameter
                                                          % omegaK = 0 (flat universe) is assumed
ifo.Constants.fs = 20000;                                 % Sampling frequency (Hz)

%% Laser-------------------------------------------------------------------
ifo.Laser.Wavelength                   = 1.064e-6;  % m  @$\lambda$@;

%% Optics------------------------------------------------------------------
ifo.Optics.SRM.CavityLength         = 24;      % m; ITM to SRM distance
% (in effect in Section @\ref{Sec:SR}@
% @$l$@ is defined as the
%  BS-2-PR distance
%  but it doesn't play any effective role because
%  the phase @$\phi$ of Eq.\ref{Eq:SRphase}@ is
%  introduced directly in the code

%TBC
ifo.Optics.PhotoDetectorEfficiency  = 1-0.14;   % photo-detection efficiency:
% it contains all the
% losses after the SR (OMC,
% PD, ...). Defined as
% @$\lambda_{PD}$ in Sec.\ref{Sec:SR}@ and
% computed in Table @\ref{Tb:PDloss}@
ifo.Optics.Loss                     = 75e-6/2;  % average per mirror power loss.
% the RTL loss @$\mathcal{L}$@ used
% in @Eq.\ref{Eq:CavityLosses} is $2\times$@ larger
% Its value is stated in
% the @Eq.\ref{Eq:RTLReq}@
ifo.Optics.BSLoss  = 1510.0e-6;                 % power loss near beamsplitter
% see Section @\ref{Sec:OptLosses}@
ifo.Optics.coupling = 0.997;                    % mismatch btwn arms & SRC modes; used to
% calculate an effective r_srm
% see Section @\ref{Sec:OptLosses}@
%% Parameter describing thermal lensing --------------------------------------
% The presumably dominant effect of a thermal lens in the ITMs is an increased
% mode mismatch into the SRC, and thus an increased effective loss of the SRC.
% This increase is estimated by calculating the round-trip loss S in the SRC as
% 1-S = |<Psi|exp(i*phi)|Psi>|^2, where
% |Psi> is the beam hitting the ITM and
% phi = P_coat*phi_coat + P_subs*phi_subs
% with phi_coat & phi__subs the specific lensing profiles
% and P_coat & P_subst the power absorbed in coating and substrate
%
% This expression can be expanded to 2nd order and is given by
% S= s_cc P_coat^2 + 2*s_cs*P_coat*P_subst + s_ss*P_subst^2
% s_cc, s_cs and s_ss where calculated analytically by Phil Wilems (4/2007)

%TBC
ifo.TCS.s_cc=7.024; % Watt^-2
ifo.TCS.s_cs=7.321; % Watt^-2
ifo.TCS.s_ss=7.631; % Watt^-2

% The hardest part to model is how efficient the TCS system is in
% compensating this loss. Thus as a simple Ansatz we define the
% TCS efficiency TCSeff as the reduction in effective power that produces
% a phase distortion. E.g. TCSeff=0.99 means that the compensated distortion
% of 1 Watt absorbed is eqivalent to the uncompensated distortion of 10mWatt.
% The above formula thus becomes:
% S= s_cc P_coat^2 + 2*s_cs*P_coat*P_subst + s_ss*P_subst^2 * (1-TCSeff)^2
%
% To avoid iterative calculation we define TCS.SCRloss = S as an input
% and calculate TCSeff as a bench output.
% TCS.SRCloss is incorporated as an additional loss in the SRC

ifo.TCS.SRCloss=300.0e-6; % V.Fafone March 2012

%% Seismic and Gravity Gradient Parameters--------VIRGO
%
% reviewed (22/03/2012) by M.Punturo, I.Fiori and P.Ruggi
%
% Seismic noise section
%ifo.Seismic.sp=[4e-8 4e-8 0.1 3.4 0.05 0.04 8.0 0.1 5e-3 44 2]; % Quiet seism
%ifo.Seismic.fi=[0.4 0.6 0.6];                                   % Quiet seism
ifo.Seismic.sp=[4e-8 4e-8 12.0 3.5 0.5 0.04 8.0 0.1 5e-3 44 2]; % Noisy seism
ifo.Seismic.fi=[0.4 0.6 1.2];                                   % Noisy seism
%
% common part
ifo.Seismic.Qi=[3 3 3];
ifo.Seismic.PoWi=[-1 -1 1]; %-1 = pole; 1 = zero


% Gravity Gradient section
ifo.Seismic.Rho = 1.8e3;            % kg/m^3; density of the ground near the mirror
% values from M.Beket thesis
ifo.Seismic.Beta = 0.58;           % quiet times beta = 0.35-0.60, noisy times beta = 0.15-1.4
%ifo.Seismic.Beta = 2*sqrt(pi)/3;           % quiet times beta = 0.35-0.60, noisy times beta = 0.15-1.4

%% Suspension: SI Units----------------------------------------------------

% This part replaces the orginially used suspension part from Advanced
% LIGO. This set of suspension parameters only works with suspR_AdV.m.
% Proper documentation of this suspension thermal noise model can be found
% in VIR-015A-09 @\cite{Piergiovanni2009}@.
%
% to update when the payload design will be available
%
% The SA modelling is introduced through its Transfer Function (zero-poles)
% loaded by an external text file generated through Octopus by P.Ruggi
%
% ifo.Suspension.SA_pz = importdata('fullSA_TF_v00r01.txt', ' ', 0);
% ifo.Suspension.SA_fnorm = 10;   % normalization frequency
% ifo.Suspension.SA_Anorm=6.1106e-017;    % TF amplitude at fnorm
%
% last stage section
%
ifo.Suspension.Temp = ifo.Constants.Temp;
ifo.Suspension.VHCoupling.theta = 1e-3;        % vertical-horizontal x-coupling

ifo.Suspension.pendulum.weq=1; %%(33)multiplication factor for the suspension thermal  
                                %%noise taking into account the extralosses
                                %%on the violin modes
                                %%calculated from the violin Q measurements during
                                %%the O3 commissioning (P.Puppo 26-9-2018)
ifo.Suspension.Silica.Rho    = 2.2e3;          % Kg/m^3;
ifo.Suspension.Silica.C      = 772;            % J/Kg/K;
ifo.Suspension.Silica.K      = 1.38;           % W/m/kg;
ifo.Suspension.Silica.Alpha  = 3.9e-7;         % 1/K;
%ifo.Suspension.Silica.Alpha  = 5.1e-7;          %% USED IN BENCH4
ifo.Suspension.Silica.dlnEdT = 1.52e-4;        % (1/K), dlnE/dT
ifo.Suspension.Silica.Phi    = 4.1e-10*ifo.Suspension.pendulum.weq;        % from G Harry e-mail to NAR 27April06 dimensionless units
ifo.Suspension.Silica.Y      = 7.2e10;        % Pa; Youngs Modulus
%ifo.Suspension.Silica.Y      = 7.27e10;	   % Young's modulus %%USED IN BENCH 4
ifo.Suspension.Silica.Dissdepth = 1.5e-2;      % from G Harry e-mail to NAR 27April06

ifo.Suspension.Silicon.Rho    = 2331.5;          % Kg/m^3;
ifo.Suspension.Silicon.C      = 3.3665;            % J/Kg/K;   @20K
ifo.Suspension.Silicon.K      = 5088.3;           % W/m/kg;  @20K
ifo.Suspension.Silicon.Alpha  = -6.3e-8;         % 1/K; @20K
ifo.Suspension.Silicon.dlnEdT = 0;        % (1/K), dlnE/dT %%Silica
ifo.Suspension.Silicon.Phi    = 1e-9;        % 
ifo.Suspension.Silicon.Y      = 1.63e11;        % Pa; Youngs Modulus
ifo.Suspension.Silicon.sigma  = 0.22;
ifo.Suspension.Silicon.Dissdepth = 5e-13/ifo.Suspension.Silicon.Phi;      % from G Harry e-mail to NAR 27April06

ifo.Suspension.Sapphire.Rho    = 3997.6;          % Kg/m^3;
ifo.Suspension.Sapphire.C      = 7.0989e-001;            % J/Kg/K;   @20K
ifo.Suspension.Sapphire.K      = 6675;           % W/m/kg;  @20K
ifo.Suspension.Sapphire.Alpha  = -2.8923e-009;         % 1/K; @20K
ifo.Suspension.Sapphire.dlnEdT = 1.52e-4;        % (1/K), dlnE/dT %%Silica
ifo.Suspension.Sapphire.Phi    = 3e-9;        % 1e-8
ifo.Suspension.Sapphire.Y      = 3.95e11;        % Pa; Youngs Modulus
ifo.Suspension.Sapphire.Dissdepth = 5e-13/ifo.Suspension.Sapphire.Phi;      % 5e-14/ifo.Suspension.Sapphire.Phi; 


ifo.Suspension.C85Steel.Rho    =  7900;         % from producer communication (WAGNER spa)
ifo.Suspension.C85Steel.C      =  502;	         	%    " "
ifo.Suspension.C85Steel.K      =  50;		          %	" "
ifo.Suspension.C85Steel.Alpha  =  14e-6;		 % 	" "
ifo.Suspension.C85Steel.Y      = 200e9;           %     "  "
% ifo.Suspension.C85Steel.dlnEdT = -2.782e-4;   % WRONG NUMBER, true for maraging!!!
ifo.Suspension.C85Steel.dlnEdT = -1.3e-4		% value found for UNS G10860, similar composition
ifo.Suspension.C85Steel.Phi    =  1e-3;		%% logbook entry 34255, See note VIR-0316E-16 (P.Puppo) for detail of evaluation.

%ifo.Suspension.C85Steel.Phi    =  1e-4;	%% M.Punturo, entry 22436 (20/03/2009) Virgo logbook

ifo.Suspension.C85Steel.Dissdepth = 0;      %Used in suspR2_AdV_steel (5/5/2017 P.Puppo)

ifo.Suspension.MaragingSteel.Rho = 7425;    % Maraging steel data from P.Puppo
ifo.Suspension.MaragingSteel.C   = 460;
ifo.Suspension.MaragingSteel.K   = 24.6;
ifo.Suspension.MaragingSteel.Alpha  = 17.925e-6;
ifo.Suspension.MaragingSteel.dlnEdT = -2.98e-4;
ifo.Suspension.MaragingSteel.Phi  = 1e-4;
ifo.Suspension.MaragingSteel.Y  = 189e9;
ifo.Suspension.MaragingSteel.Dissdepth = 0;

ifo.Suspension.Stage(1).Mass =220;             %Mirror mass in kg;
ifo.Suspension.Stage(2).Mass =20000;             %unused in the new payload design
ifo.Suspension.Stage(3).Mass =220;            %Mass of marionette
ifo.Suspension.Mario.QV = 1e12;               % Viscous Q of the Marionette; 

% Value measured on beamsplitter payload of Advanced Virgo


ifo.Suspension.Optcyl=0; %Switch 0=cylindrical fibres; 1=optimized fibres
%----------Optimized fibres-----------------------
ifo.Suspension.Stage(1).WireDiameter1 = 2.2e-3; %diameter of the first head
ifo.Suspension.Stage(1).WireDiameter2 = 2.2e-3; %diameter of the middle part
ifo.Suspension.Stage(1).WireDiameter3 = 2.2e-3; %diameter of the second head
ifo.Suspension.Stage(1).Length1 = 0.0165;         %length of the first head
ifo.Suspension.Stage(1).Length2 = 0.7;          %length of the middle part
ifo.Suspension.Stage(1).Length3 = 0.0165;         %length of the second head
%----------Cylindrical fibres----------------------
ifo.Suspension.Stage(1).WireDiameter = 2.3e-3;  %fibre's diameter
ifo.Suspension.Stage(1).Length = 1.2;           %fibre's length
%--------------------------------------------------

%%%Steel Suspension%%%%%%%%%%%%%%%%%%%%%%%%%%
ifo.Suspension.C85Steel.Diameter=0.3e-3;   %Steel wires diameter 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ifo.Suspension.Stage(2).WireDiameter = 400e-6;  %RM wire's diameter
ifo.Suspension.Stage(3).WireDiameter = 5e-3; %Marionette wire's diameter

ifo.Suspension.Stage(2).Length = 0.7;           %RM wire's length
ifo.Suspension.Stage(3).Length = 1.005;         %Marionette wire's length

ifo.Suspension.Stage(1).NWires = 4;             %Numbers of wires in mirror suspension
ifo.Suspension.Stage(2).NWires = 4;             %Numbers of wires in RM suspension
ifo.Suspension.Stage(3).NWires = 1;             %Numbers of wires in marionette suspension

ifo.Suspension.Stage(1).Qvh=1e20;               %Viscous Q of mirror for horizontal motion
ifo.Suspension.Stage(2).Qvh=1e20;                %Viscous Q of reference mass for horizontal motion
ifo.Suspension.Stage(3).Qvh=ifo.Suspension.Mario.QV; %Viscous Q of marionette for horizontal motion

ifo.Suspension.Stage(1).Qvv=1e20;               %Viscous Q of mirror for vertical motion
ifo.Suspension.Stage(2).Qvv=1e5;                %Viscous Q of reference mass for vertical motion 
ifo.Suspension.Stage(3).Qvv=ifo.Suspension.Mario.QV; %Viscous Q of marionette for verical motion

%MIRROR SUSPENSION MATERIAL (Sapphire)

ifo.Suspension.Stage(1).Rho=ifo.Suspension.Sapphire.Rho;
ifo.Suspension.Stage(1).C=ifo.Suspension.Sapphire.C;          
ifo.Suspension.Stage(1).K=ifo.Suspension.Sapphire.K ;           % W/m/kg
ifo.Suspension.Stage(1).Alpha=ifo.Suspension.Sapphire.Alpha;         
ifo.Suspension.Stage(1).dlnEdT=ifo.Suspension.Sapphire.dlnEdT;        % (1/K), dlnE/dT 
ifo.Suspension.Stage(1).Phi=ifo.Suspension.Sapphire.Phi;          
ifo.Suspension.Stage(1).Y=ifo.Suspension.Sapphire.Y;        % Pa; Youngs Modulus 
%ifo.Suspension.Stage(1).sigma=ifo.Suspension.Sapphire.sigma;  
ifo.Suspension.Stage(1).Dissdepth=ifo.Suspension.Sapphire.Dissdepth;     

%RM SUSPENSION MATERIAL (Silicon)

ifo.Suspension.Stage(2).Rho=ifo.Suspension.Silicon.Rho;
ifo.Suspension.Stage(2).C=ifo.Suspension.Silicon.C;          
ifo.Suspension.Stage(2).K=ifo.Suspension.Silicon.K ;           % W/m/kg
ifo.Suspension.Stage(2).Alpha=ifo.Suspension.Silicon.Alpha;         
ifo.Suspension.Stage(2).dlnEdT=ifo.Suspension.Silicon.dlnEdT;        % (1/K), dlnE/dT 
ifo.Suspension.Stage(2).Phi=ifo.Suspension.Silicon.Phi;          
ifo.Suspension.Stage(2).Y=ifo.Suspension.Silicon.Y;        % Pa; Youngs Modulus 
ifo.Suspension.Stage(2).sigma=ifo.Suspension.Silicon.sigma;  
ifo.Suspension.Stage(2).Dissdepth=ifo.Suspension.Silicon.Dissdepth; 


%MARIONETTE SUSPENSION MATERIAL (Sapphire)

ifo.Suspension.Stage(3).Rho=ifo.Suspension.Sapphire.Rho;
ifo.Suspension.Stage(3).C=ifo.Suspension.Sapphire.C;          
ifo.Suspension.Stage(3).K=ifo.Suspension.Sapphire.K ;           % W/m/kg
ifo.Suspension.Stage(3).Alpha=ifo.Suspension.Sapphire.Alpha;         
ifo.Suspension.Stage(3).dlnEdT=ifo.Suspension.Sapphire.dlnEdT;        % (1/K), dlnE/dT 
ifo.Suspension.Stage(3).Phi=ifo.Suspension.Sapphire.Phi;          
ifo.Suspension.Stage(3).Y=ifo.Suspension.Sapphire.Y;        % Pa; Youngs Modulus 
%ifo.Suspension.Stage(3).sigma=ifo.Suspension.Sapphire.sigma;  
ifo.Suspension.Stage(3).Dissdepth=ifo.Suspension.Sapphire.Dissdepth; 
%% Dielectric coating material parameters----------------------------------
ifo.Materials.Coating.weq=1;  %%(1.8)multiplication factor for the coating noise
                                %%taking into account the extralosses on the mirror
                                %%calculated from the Q measurements during
                                %%the O3 commissioning (P.Puppo 26-9-2018)

%% high index material: tantala
ifo.Materials.Coating.Yhighn = 140e9;               % @$E_{n1}$ in Eq.\ref{eq:TheNoiseMirr06c}@
ifo.Materials.Coating.Sigmahighn = 0.23;            % @$\sigma_{n1}$ in Eq.\ref{eq:TheNoiseMirr06c}@
ifo.Materials.Coating.CVhighn = 2.1e6;              % Specific heat per volume unit
% used in Eq.@\ref{Eq:AverageSpecificHeat}@
% see Crooks et al@\cite{0264-9381-23-15-014}@
ifo.Materials.Coating.Alphahighn = 3.6e-6;          % 3.6e-6 Fejer et al, 5e-6 from Braginsky
ifo.Materials.Coating.Betahighn = 1.4e-5;           % dn/dT, value Gretarrson (G070161)
%
ifo.Materials.Coating.ThermalDiffusivityhighn = 33;  % Fejer et al
ifo.Materials.Coating.Phihighn = 2.3e-4;
ifo.Materials.Coating.Indexhighn = 2.035;    % Measured at LMA, Email from Laurent (5/3/2009)

%% low index material: silica
ifo.Materials.Coating.Ylown = 72e9;
ifo.Materials.Coating.Sigmalown = 0.17;
ifo.Materials.Coating.CVlown = 1.6412e6;             % Crooks et al, Fejer et al
ifo.Materials.Coating.Alphalown = 5.1e-7;            % Fejer et al
ifo.Materials.Coating.Betalown = 8e-6; % dn/dT,  (ref. 14)
ifo.Materials.Coating.ThermalDiffusivitylown = 1.38; % Fejer et al
ifo.Materials.Coating.Philown = 4.0e-5;
ifo.Materials.Coating.Indexlown = 1.458;         % Measured at LMA, Email from Laurent (5/3/2009)

%%Substrate Material parameters--------------------------------------------

%ifo.Materials.Substrate.c2  = 7.6e-12;                  % Coeff of freq depend.
% term for bulk mechanical loss, 7.15e-12 for Sup2
%ifo.Materials.Substrate.MechanicalLossExponent=0.77;    % Exponent for freq dependence of silica loss,
% 0.822 for Sup2
ifo.Materials.Substrate.phi   =  1.5e-8;  %%For Silicon at low temp (around 20K)
ifo.Materials.Substrate.Alphas = 5.2e-12;              % Surface loss limit (ref. 12)
ifo.Materials.Substrate.MirrorY    = ifo.Suspension.Silicon.Y         % N/m^2; Youngs modulus (ref. 4)
ifo.Materials.Substrate.MirrorSigma = ifo.Suspension.Silicon.sigma;           % Kg/m^3; Poisson ratio (ref. 4)
ifo.Materials.Substrate.MassDensity = ifo.Suspension.Silicon.Rho;           % Kg/m^3; (ref. 4)
ifo.Materials.Substrate.MassAlpha = ifo.Suspension.Silicon.Alpha;            % 1/K; thermal expansion coeff. (ref. 4)
ifo.Materials.Substrate.MassCM = ifo.Suspension.Silicon.C;                  % J/Kg/K; specific heat (ref. 4)
ifo.Materials.Substrate.MassKappa = ifo.Suspension.Silicon.K;              % J/m/s/K; thermal conductivity (ref. 4)
%ifo.Materials.Substrate.RefractiveIndex = 1.45;        % mevans 25 Apr 2008
ifo.Materials.Substrate.RefractiveIndex = 3.45;        % Value for silicon
%
% The following data are extracted from the MIR chapter of the AdV TDR @\cite{AdVTDR2012}@
%
%MIRROR GEOMETRY
ifo.Materials.MassRadius = 0.275;                      % m;
ifo.Materials.MassThickness = 0.230;                   % m;

%BEAM GEOMETRY
%ifo.Optics.Curvature.ITM = 1530;                      % ROC of ITM
%ifo.Optics.Curvature.ETM = 1530;                      % ROC of ETM

ifo.Optics.Curvature.ITM = 1420;                      % ROC of ITM
ifo.Optics.Curvature.ETM = 1683;                      % ROC of ETM

%ifo.Optics.Diameter.ITM = .34;                        % Coating diameter
%ifo.Optics.Diameter.ETM = .34;                        % Coating diameter
ifo.Optics.Diameter.ITM = .33;                        % baffle aperture (1 cm less than the
ifo.Optics.Diameter.ETM = .33;                        % Coating diameter) Sec.2.3.3 of @\cite{AdVTDR2012}@

ifo.Optics.SubstrateAbsorption = 0.3e-4;              % 1/m; bulk absorption coef
ifo.Optics.pcrit = 10;                                % W; tolerable heating power (factor 1 ATC)

% These are now computed in precompIFO
%ifo.Optics.ITM.BeamRadius = 0.0554;                     % m; 1/e^2 power%radius
%ifo.Optics.ETM.BeamRadius = 0.065;                     % m; 1/e^2 power radius

ifo.Optics.ITM.CoatingAbsorption = 1.0e-6;            % absorption of ITM

%FINESSE, SR-PR PARAMETERS

ifo.Optics.ITM.Transmittance  = 0.014;              % Transmittance of ITM
ifo.Optics.ETM.Transmittance  = 1e-6;               % Transmittance of ETM

ifo.Optics.PRM.Transmittance  = 0.05;               % PRM trasmittance

% coating layer optical thicknesses - mevans June 2008
ifo.Optics.ITM.CoatingThicknessLown = 0.308;
ifo.Optics.ITM.CoatingThicknessCap = 0.5;

ifo.Optics.ETM.CoatingThicknessLown = 0.27;
ifo.Optics.ETM.CoatingThicknessCap = 0.5;

% new Coating Brownian noise evaluation based on the talk made
% by Massimo Granata (VIR-0204A-15) and with a phone call with him:
% loss angle of the coating is given directly by them based on
% experimental measurements
%
ifo.Optics.ITM.phi=1.4e-4;                          % coating loss angle for ITM
ifo.Optics.ETM.phi=2.0e-4;                          % coating loss angle for ETM
ifo.Optics.ITM.t_tio2ta2o5=734e-9;                  % Total thickness of Ta2O5 ITM
ifo.Optics.ETM.t_tio2ta2o5=2129e-9;                 % Total thickness of Ta2O5 ETM
ifo.Optics.ITM.t_sio2=2092e-9;                      % Total thickness of SiO2 ITM
ifo.Optics.ETM.t_sio2=3787e-9;                      % Total thickness of SiO2 ETM


% Output Mode Cleaner parameters
% used to compute OMC thermorefractive noise
%
ifo.Optics.OMC.beta = -0.8e-5;                      % Temperature dependence of the
% refraction index in
% the OMC
ifo.Optics.OMC.rho = 2200;                          % Density of the OMC glass (kg/m^3)
ifo.Optics.OMC.Lgeo = 62.0e-3;                      % geometrical length
ifo.Optics.OMC.Lrt = 4*ifo.Optics.OMC.Lgeo;         % Round trip length
ifo.Optics.OMC.K = 1.38;                            % Thermal conductivity (W/m/K)
ifo.Optics.OMC.C = 739;                             % specific heat (J/Kg/K)
ifo.Optics.OMC.w = 321e-6;                          % beam waist for radius
% of curvature = 1700 m
ifo.Optics.OMC.Pdf = 80e-3;                         % Power in the carrier TEM00
% at the dark fringe
% (W)
ifo.Optics.OMC.DLomc = 6e-13;                       % OMC locking accuracy (R.Guaty)
ifo.Optics.OMC.F = 151;                             % OMC cavity finesse
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Squeezing
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ifo.Squeezer.AmplitudedB = 6;          % SQZ amplitude [dB]
ifo.Squeezer.InjectionLoss = 0.01;      % Injection loss to Sqz (up to Forward Propagation Losses in DET)
ifo.Squeezer.SQZAngle = 0*pi/180;       % SQZ phase [radians]
ifo.Squeezer.PhaseNoise = 15e-3;        % Total SQZ phase noise [radians]

%% Parameters for frequency dependent squeezing
ifo.Squeezer.FilterCavity.fdetune = -33;     % detuning [Hz]
ifo.Squeezer.FilterCavity.L = 285;           % (100 default) cavity length
ifo.Squeezer.FilterCavity.Ti = 300e-6;       % input mirror trasmission [Power]
ifo.Squeezer.FilterCavity.Te = 0e-6;         % end mirror trasmission
ifo.Squeezer.FilterCavity.Lrt = 100e-6;      % round-trip loss in the cavity
ifo.Squeezer.FilterCavity.Rot = 0*pi/180;    % phase rotation after cavity

%%Variational Output Parameters--------------------------------------------
% Define the output filter cavity chain
%   None = ignore the output filter settings
%   Chain = apply filter cavity chain
%   Optimal = find the best readout phase
ifo.OutputFilter.Type = 'None';
end
