function [noise,Delta,dil]=suspR2_AdV(f,ifopar)

% Francesco Piergiovanni (piergiovanni@fi.infn.it)
% Paola Puppo (paola.puppo@ego-gw.it)
% Michele Punturo (michele.punturo@pg.infn.it)

%  September 2012. Modified by P. Puppo.
%  Suspension thermal noise is obtained by the fluctuation dissipation theorem approach(see  Virgo note VIR-015A-09). 
%  A complete elastic computation for the mirror stage is performed (violin modes are taken into account). 
%  In the new design of the Last Stage suspension the reaction mass is suppressed and only the marionette and the mirror are suspended to the filter 7
%  as a cascade of pendula.
%  A low frequency approximation (elastic energy << gravitational energy) is considered for marionette and RF stages.
%  INPUT: frequency (f), list of parameters(ifopar). 
%  OUTPUT: suspension thermal noise PSD (noise).

% In this routine, indexes 1 refers to marionette. Mirror's stage parameter has no index.

ifo=ifopar;

% General parameter 
g=ifo.Constants.g; 
kb=ifo.Constants.kB;
Temp=ifo.Suspension.Temp;
Larm=ifo.Infrastructure.Length;
% Horizontal to Vertical coupling
thetaHV=ifo.Suspension.VHCoupling.theta;

%---------- Mirror pendulum ------------------------------------
%Sapphire thermo-mechanical properties
alpha=ifo.Suspension.Stage(1).Alpha;
beta=ifo.Suspension.Stage(1).dlnEdT;
C=ifo.Suspension.Stage(1).C;
K=ifo.Suspension.Stage(1).K;
rho=ifo.Suspension.Stage(1).Rho;
phi0=ifo.Suspension.Stage(1).Phi ; 
ds=ifo.Suspension.Stage(1).Dissdepth;
E0=ifo.Suspension.Stage(1).Y; 

Optcyl=ifo.Suspension.Optcyl; %Switch cylindrical/optimized fibres

m=ifo.Suspension.Stage(1).Mass; 
N=ifo.Suspension.Stage(1).NWires;

T=m*g/N; %Tension per fibre

w=2*pi*f;

if Optcyl==0,
    L=ifo.Suspension.Stage(1).Length;
    d=ifo.Suspension.Stage(1).WireDiameter;
    r=d/2;
    II=pi/4*r^4;
else
    L1=ifo.Suspension.Stage(1).Length1;
    L2=ifo.Suspension.Stage(1).Length2;
    L3=ifo.Suspension.Stage(1).Length3;
    d1=ifo.Suspension.Stage(1).WireDiameter1;
    d2=ifo.Suspension.Stage(1).WireDiameter2;
    d3=ifo.Suspension.Stage(1).WireDiameter3;
    r1=d1/2;
    r2=d2/2;
    r3=d3/2;
    L=L1+L2+L3;
end



delta=1e-3;

z=zeros(length(f),3000);
x=zeros(length(f),3000);
TotEnergy=zeros(1,length(f));
Energy=zeros(length(f),3000);
phiST=zeros(1,length(f));
phithT=zeros(1,length(f));

for i=1:length(w),
if Optcyl==0; % Cylindrical fibres
    %Surface contribution for circular cross section fibres (horizontal
    %motion)
    mu=4/r;
    phiST(i)=phi0*(1+mu.*ds); 
    S=pi*r^2;
    %Thermoelastic contribution
    Delta=E0*(alpha-beta*T/(S*E0)).^2*Temp/(rho*C);
    tau=0.0737*rho*C*(2*r)^2/K;
    phithT(i)=Delta*w(i)*tau/(1+w(i)^2*tau^2);  
    S0=S;
else  % Optimized fibres
    % Optimized fibres routine is called
    [z(i,:) x(i,:) dummy Energy(i,:)]=An_suspn_3(f(i),0,ifo); 
    TotEnergy(i)=sum(Energy(i,:));
    phiST(i)=0;
    phithT(i)=0;

    for j=1:length(z(i,:)),
     if z(i,j)<L1,
       r=r1;
     elseif z(i,j)<L1+L2,
       r=r2;
     else
       r=r3;
     end
     
     
    mu=4./r;
    phiS=phi0*(1+mu.*ds);
    S=pi*r^2;
    Delta=E0*(alpha-beta*T/(S*E0)).^2*Temp/(rho*C);
    tau=0.0737*rho*C*(2*r)^2/K;
    
    % Surface contribution and thermoelastic contribution are weighted by
    % the bending energy 
    
    phiST(i)=phiST(i)+phiS*Energy(i,j);
    phithT(i)=phithT(i)+Delta*w(i)*tau/(1+w(i)^2*tau^2)*Energy(i,j);
    end
    phiST(i)=phiST(i)/TotEnergy(i);
    phithT(i)=phithT(i)/TotEnergy(i);
    S0=pi*(r1^2*L1+r2^2*L2+r3^2*L3)/L;
end

phiT=phiST+0*phithT;
end
% figure(20)
% plot(phiT)
%--------------------- Marionette ---------------------

% Marionette and RM stages parameter are loaded. 
m1=ifo.Suspension.Stage(3).Mass; 
LL1=ifo.Suspension.Stage(3).Length;

dd1=ifo.Suspension.Stage(3).WireDiameter;

N1=ifo.Suspension.Stage(3).NWires;
rho1=ifo.Suspension.Stage(3).Rho;
C1=ifo.Suspension.Stage(3).C;
K1=ifo.Suspension.Stage(3).K;
alpha1=ifo.Suspension.Stage(3).Alpha;
beta1=ifo.Suspension.Stage(3).dlnEdT;
phi1=ifo.Suspension.Stage(3).Phi;
E1=ifo.Suspension.Stage(3).Y;

T1=(m1+m)*g/N1;

S1=pi*(dd1/2)^2;


% Thermoelastic contribution

Delta1=E1*(alpha1-beta1*T1/(S1*E1)).^2*Temp/(rho1*C1);

tau1=0.0737*rho1*C1*(dd1)^2/K1;


for i=1:length(w),
    phith1(i)=Delta1*w(i)*tau1/(1+w(i)^2*tau1^2);
       
end

phiT1=phith1+phi1;

M1=m+m1;
I1=pi/4*(dd1/2).^4;


% Dilution factors for marionette and RM stages
dil1=sqrt(E1*I1*N1/M1/g/LL1^2);

% Gravitational reaction constants
k0p1=M1*g/LL1*(1+dil1);

w01=sqrt(k0p1/M1);


% Horizontal viscous Q's

Q=ifo.Suspension.Stage(1).Qvh;
Q1=ifo.Suspension.Stage(3).Qvh;


% Total loss angle internal+viscous
phi1tot=dil1*phiT1+w/(Q1*w01);
kp1=k0p1*(1+1i*phi1tot);


% Reaction constants for mirror stage fused silica fibres VIR-0.15A-09
% sec. 2
for i=1:length(w),
    if Optcyl==0, %Cylindrical fibres
     E=E0*(1+1i*phiT(i));
     lambda=sqrt(1/(2*E*II)*(T+T*sqrt(1+4*E*II*w(i)^2*rho*S/T^2)));
     p=sqrt(1/(2*E*II)*(-T+T*sqrt(1+4*E*II*w(i)^2*rho*S/T^2)));    

     Kpend(i)=4*E*II*lambda*p*(lambda^3*cos(p*L)+lambda^2*sin(p*L)*p...
     +p^3*sin(p*L)+lambda*cos(p*L)*p^2)...
      /(-2*lambda*cos(p*L)*p+lambda^2*sin(p*L)-sin(p*L)*p^2);
    else % Optimized fibres
     [z(i,:) x(i,:) Fend]=An_suspn_3(f(i),phiT(i),ifo);
     Kpend(i)=4*Fend/delta;
    
    end
end

w0=sqrt(real(Kpend(1))/m);
nuo=w0/2/pi;
Kpend=real(Kpend)+1i*(imag(Kpend)+w./(w0*Q).*abs(real(Kpend)));%viscous dissipation is added
dil=sqrt(E0*II*N/m/g/L^2);
 
% Thermal noise is obtained from FDT. The equations of motion are written
% in a martix formalism Ah*Xh=B. The admittance is calculated. VIR-0.15A-09
% sec. 1.1-1.2-1.3 
Ah = zeros([2,2,length(f)]);
Ah(1,1,:)=kp1+Kpend-m1*w.^2;
Ah(1,2,:)=-Kpend;
Ah(2,1,:)=-Kpend;
Ah(2,2,:)=Kpend-m*w.^2;
B=[0 1];

for i=1:length(w),
    Xh(:,i)=linsolve(Ah(:,:,i),B');
end

admitt=1i*w.*Xh(2,:);
noise_h = 4*kb*Temp*real(admitt)./w.^2*4/Larm^2; %horizontal suspension thermal noise PSD 

% VERTICAL MOTION 

%Surface contribution for circular cross section fibres (vertical motion)
mu_v=2/r;
phiv=phi0*(1 + mu_v*ds);


wv1=2*pi*0.4; % 0.4Hz is the resonance frequency of the marionette stage due to the anti-spring system
%Vertical resonance frequency for mirror wires (from Hook's law)
wv=sqrt(4*E0*S0/L/m);

%Vertical viscous Q's
Qv=ifo.Suspension.Stage(1).Qvv;
Qv1=ifo.Suspension.Stage(3).Qvv;


% Total loss angle internal+viscous
phiv=phiv+w/(Qv*wv);
phiv1=phi1+w/(Qv1*wv1);


% Elastic constants for vertical motion
kv1=wv1^2*M1*(1+1i*phiv1);
kv=wv^2*m*(1+1i*phiv);


% Thermal noise is obtained from FDT. The equations of motion are written
% in a martix formalism Av*Xv=B. The admittance is calculated. VIR-0.15A-09
% sec. 1.5
Av = zeros([2,2,length(f)]);
Av(1,1,:)=kv1+kv-m1*w.^2;
Av(1,2,:)=-kv;
Av(2,1,:)=-kv;
Av(2,2,:)=kv-m*w.^2;
B=[0 1];

for i=1:length(w),
    Xv(:,i)=linsolve(Av(:,:,i),B');
end

admitt_v=1i*w.*Xv(2,:);
noise_v   = 4*kb*Temp*real(admitt_v)./w.^2*4/Larm^2; %vertical suspension thermal noise PSD 
noise_cv = thetaHV^2*noise_v; %vertical coupled to horizontal noise
noise=noise_h+0*noise_cv; % Total th noise PSD
strac=real(admitt)./w./phiT/2;
end    



